==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/af.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'af', {
	button: {
		title: 'Knop eienskappe',
		text: 'Teks (Waarde)',
		type: 'Soort',
		typeBtn: 'Knop',
		typeSbm: 'Stuur',
		typeRst: 'Maak leeg'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Merkhokkie eienskappe',
		radioTitle: 'Radioknoppie eienskappe',
		value: 'Waarde',
		selected: 'Geselekteer'
	},
	form: {
		title: 'Vorm eienskappe',
		menu: 'Vorm eienskappe',
		action: 'Aksie',
		method: 'Metode',
		encoding: 'Kodering'
	},
	hidden: {
		title: 'Verborge veld eienskappe',
		name: 'Naam',
		value: 'Waarde'
	},
	select: {
		title: 'Keuseveld eienskappe',
		selectInfo: 'Info',
		opAvail: 'Beskikbare opsies',
		value: 'Waarde',
		size: 'Grootte',
		lines: 'Lyne',
		chkMulti: 'Laat meer as een keuse toe',
		opText: 'Teks',
		opValue: 'Waarde',
		btnAdd: 'Byvoeg',
		btnModify: 'Wysig',
		btnUp: 'Op',
		btnDown: 'Af',
		btnSetValue: 'Stel as geselekteerde waarde',
		btnDelete: 'Verwyder'
	},
	textarea: {
		title: 'Teks-area eienskappe',
		cols: 'Kolomme',
		rows: 'Rye'
	},
	textfield: {
		title: 'Teksveld eienskappe',
		name: 'Naam',
		value: 'Waarde',
		charWidth: 'Breedte (karakters)',
		maxChars: 'Maksimum karakters',
		type: 'Soort',
		typeText: 'Teks',
		typePass: 'Wagwoord',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/af.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'af', {
	button: {
		title: 'Knop eienskappe',
		text: 'Teks (Waarde)',
		type: 'Soort',
		typeBtn: 'Knop',
		typeSbm: 'Stuur',
		typeRst: 'Maak leeg'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Merkhokkie eienskappe',
		radioTitle: 'Radioknoppie eienskappe',
		value: 'Waarde',
		selected: 'Geselekteer',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Vorm eienskappe',
		menu: 'Vorm eienskappe',
		action: 'Aksie',
		method: 'Metode',
		encoding: 'Kodering'
	},
	hidden: {
		title: 'Verborge veld eienskappe',
		name: 'Naam',
		value: 'Waarde'
	},
	select: {
		title: 'Keuseveld eienskappe',
		selectInfo: 'Info',
		opAvail: 'Beskikbare opsies',
		value: 'Waarde',
		size: 'Grootte',
		lines: 'Lyne',
		chkMulti: 'Laat meer as een keuse toe',
		required: 'Required', // MISSING
		opText: 'Teks',
		opValue: 'Waarde',
		btnAdd: 'Byvoeg',
		btnModify: 'Wysig',
		btnUp: 'Op',
		btnDown: 'Af',
		btnSetValue: 'Stel as geselekteerde waarde',
		btnDelete: 'Verwyder'
	},
	textarea: {
		title: 'Teks-area eienskappe',
		cols: 'Kolomme',
		rows: 'Rye'
	},
	textfield: {
		title: 'Teksveld eienskappe',
		name: 'Naam',
		value: 'Waarde',
		charWidth: 'Breedte (karakters)',
		maxChars: 'Maksimum karakters',
		required: 'Required', // MISSING
		type: 'Soort',
		typeText: 'Teks',
		typePass: 'Wagwoord',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'URL'
	}
} );
